using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using MadCap.HelpViewerEmbeddedClient;

namespace HelpViewerEmbeddedClientTester
{
    public partial class Form1 : Form , ICSHIDProvider
    {
        private HelpViewerEmbeddedClient mHelpSystemClient;

        public string HelpSystemCSHID
        {
            get { return "HVEC"; }
        }

        public Form1()
        {
            InitializeComponent();

            Application.Idle += new EventHandler(Application_Idle);

			//

			Uri	basePath	= new Uri( Application.StartupPath );
			Uri	path		= new Uri( basePath, "../SampleHelpSystem/Manual.mchelp" );

			mHelpSystemPath.Text = path.LocalPath;
			mHelpSystemClient = new HelpViewerEmbeddedClient( "My Test Help System", Resources.HelpSystemIcon );

			try
			{
				mHelpSystemClient.Load( mHelpSystemPath.Text );
			}
			catch ( ArgumentException ex )
			{
				MessageBox.Show( ex.Message );
				return;
			}

            mHelpSystemClient.HelpSystem.DynamicHelpPanel = mTopicPanel;
            mHelpSystemClient.HelpSystem.EnableDynamicHelp = false;
            mHelpSystemClient.HelpSystem.EnableHelpButton(this);
        }

        void Application_Idle(object sender, EventArgs e)
        {
            mShowTopicButton.Enabled = mHelpSystemClient != null;
            mSearchButton.Enabled = mHelpSystemClient != null;
            mShowHelpButton.Enabled = mHelpSystemClient != null;
            mLoadTopicButton.Enabled = mHelpSystemClient != null;
            mEmbeddedSearchButton.Enabled = mHelpSystemClient != null;
        }

        private void mPickButton_Click(object sender, EventArgs e)
        {
            OpenFileDialog dlg = new OpenFileDialog();
            using (dlg)
            {
                dlg.Filter = "";
                dlg.Filter += /*UI:file filter*/ "MadCap Help System (*.mchelp)|*.mchelp";
                dlg.Multiselect = false;

                DialogResult dr = dlg.ShowDialog();

                if (dr == DialogResult.OK)
                {
                    mHelpSystemPath.Text = dlg.FileName;
                }

                if (mHelpSystemClient == null)
                {
                    mHelpSystemClient = new HelpViewerEmbeddedClient();
                }

                try
				{
					mHelpSystemClient.Load( mHelpSystemPath.Text );
				}
				catch ( ArgumentException ex )
				{
					MessageBox.Show( ex.Message );
					return;
				}

                mHelpSystemClient.HelpSystem.DynamicHelpPanel = mTopicPanel;
                mHelpSystemClient.HelpSystem.EnableDynamicHelp = false;
                mHelpSystemClient.HelpSystem.EnableHelpButton(this);
            }
        }

        private void mShowTopicButton_Click(object sender, EventArgs e)
        {
            if (mHelpSystemClient != null)
            {
                mHelpSystemClient.HelpSystem.ShowTopic(mCSHID.Text);
            }
        }

        private void mSearchButton_Click(object sender, EventArgs e)
        {
            if (mHelpSystemClient != null)
            {
				string	cshid	= mCSHID.Text;

				if ( string.IsNullOrEmpty( cshid ) )
				{
					mHelpSystemClient.HelpSystem.Search( mSearch.Text );
				}
				else
				{
					mHelpSystemClient.HelpSystem.Search( mSearch.Text, cshid );
				}
            }
        }

        private void mShowHelpButton_Click(object sender, EventArgs e)
        {
            if (mHelpSystemClient != null)
            {
                mHelpSystemClient.HelpSystem.ShowHelp();
            }
        }

        private void mLoadTopicButton_Click(object sender, EventArgs e)
        {
            if (mHelpSystemClient != null)
            {
                mHelpSystemClient.HelpSystem.DynamicHelpPanel = mTopicPanel;
                mHelpSystemClient.HelpSystem.LoadTopic(mCSHID.Text);
            }
        }

        private void mEmbeddedSearchButton_Click(object sender, EventArgs e)
        {
            if (mHelpSystemClient != null)
            {
                mHelpSystemClient.HelpSystem.SearchPanel = mSearchPanel;
                mSearchPanel.Refresh();

                mHelpSystemClient.HelpSystem.EmbeddedSearch(mSearch.Text);
            }
 
        }

        private void mTestButton_Click(object sender, EventArgs e)
        {
            using (DialogWithCSHID dlg = new DialogWithCSHID())
            {
                mHelpSystemClient.HelpSystem.EnableHelpButton(dlg);

                dlg.ShowDialog(this);
            }
        }
    }
}